changeset 54233:4da084c4e7a7

Doc fix.
author Vinicius Jose Latorre <viniciusjl@ig.com.br>
date Tue, 02 Mar 2004 04:54:04 +0000
parents e9a21f90fd82
children e1003d782dc6
files lisp/ChangeLog lisp/ps-print.el
diffstat 2 files changed, 53 insertions(+), 12 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Tue Mar 02 00:15:01 2004 +0000
+++ b/lisp/ChangeLog	Tue Mar 02 04:54:04 2004 +0000
@@ -1,3 +1,14 @@
+2004-03-03  Vinicius Jose Latorre  <viniciusjl@ig.com.br>
+
+	* ps-print.el: Doc fix.
+	(ps-print-version): New version number (6.6.3).
+	(ps-right-header, ps-right-footer, ps-left-header, ps-left-footer):
+	Docstring fix.
+	(ps-kill-emacs-check): Check if ps-print temporary buffer is killed
+	before printing.
+	(ps-time-stamp-yyyy-mm-dd): New fun.
+	(ps-time-stamp-iso8601): Alias for ps-time-stamp-yyyy-mm-dd.
+
 2004-03-02  Kim F. Storm  <storm@cua.dk>
 
 	* gdb-ui.el (gdb-mouse-toggle-breakpoint): Remove debug message.
--- a/lisp/ps-print.el	Tue Mar 02 00:15:01 2004 +0000
+++ b/lisp/ps-print.el	Tue Mar 02 04:54:04 2004 +0000
@@ -1,7 +1,7 @@
 ;;; ps-print.el --- print text from the buffer as PostScript
 
 ;; Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
 ;; 2003 Free Software Foundation, Inc.
 
 ;; Author: Jim Thompson (was <thompson@wg2.waii.com>)
 ;;	Jacques Duthen (was <duthen@cegelec-red.fr>)
@@ -10,12 +10,12 @@
 ;; Maintainer: Kenichi Handa <handa@etl.go.jp> (multi-byte characters)
 ;;	Vinicius Jose Latorre <viniciusjl@ig.com.br>
 ;; Keywords: wp, print, PostScript
-;; Time-stamp: <2003/07/10 19:19:12 vinicius>
-;; Version: 6.6.2
+;; Time-stamp: <2004/02/29 00:07:55 vinicius>
+;; Version: 6.6.3
 ;; X-URL: http://www.cpqd.com.br/~vinicius/emacs/
 
-(defconst ps-print-version "6.6.2"
-  "ps-print.el, v 6.6.2 <2003/07/10 vinicius>
+(defconst ps-print-version "6.6.3"
+  "ps-print.el, v 6.6.3 <2004/02/29 vinicius>
 
 Vinicius's last change version -- this file may have been edited as part of
 Emacs without changes to the version number.  When reporting bugs, please also
@@ -1213,6 +1213,9 @@
 ;;
 ;; [vinicius] Vinicius Jose Latorre <viniciusjl@ig.com.br>
 ;;
+;;    20040229
+;;	 `ps-time-stamp-yyyy-mm-dd', `ps-time-stamp-iso8601'
+;;
 ;;    20010619
 ;;	 `ps-time-stamp-locale-default'
 ;;
@@ -1261,7 +1264,7 @@
 ;;
 ;; [keinichi] 19990509 Kein'ichi Handa <handa@etl.go.jp>
 ;;
-;; `ps-print-region-function'
+;;    `ps-print-region-function'
 ;;
 ;; [vinicius] Vinicius Jose Latorre <viniciusjl@ig.com.br>
 ;;
@@ -1274,7 +1277,7 @@
 ;;
 ;; [keinichi] 19980819 Kein'ichi Handa <handa@etl.go.jp>
 ;;
-;; Multi-byte buffer handling.
+;;    Multi-byte buffer handling.
 ;;
 ;; [vinicius] Vinicius Jose Latorre <viniciusjl@ig.com.br>
 ;;
@@ -1370,9 +1373,11 @@
 ;; Thanks to David X Callaway <dxc@xprt.net> for helping debugging PostScript
 ;; level 1 compatibility.
 ;;
 ;; Thanks to Colin Marquardt <colin.marquardt@usa.alcatel.com> for upside-down,
 ;; line number step, line number start and zebra stripe follow suggestions, and
 ;; for XEmacs beta-tests.
 ;;
 ;; Thanks to Klaus Berndl <klaus.berndl@sdm.de> for user defined PostScript
 ;; prologue code suggestion, for odd/even printing suggestion and for
@@ -3111,7 +3116,9 @@
 For symbols with bound functions, the function is called and should return a
 string to be inserted into the array.  For symbols with bound values, the value
 should be a string to be inserted into the array.  In either case, function or
-variable, the string value has PostScript string delimiters added to it."
+variable, the string value has PostScript string delimiters added to it.
+
+If symbols are unbounded, they are silently ignored."
   :type '(repeat (choice :menu-tag "Left Header"
 			 :tag "Left Header"
 			 string symbol))
@@ -3135,6 +3142,11 @@
 
    `ps-time-stamp-mon-dd-yyyy'		Return date as \"Jun 18 2001\".
 
+   `ps-time-stamp-yyyy-mm-dd'		Return date as \"2001-06-18\" (ISO
+					date).
+
+   `ps-time-stamp-iso8601'		Alias for `ps-time-stamp-yyyy-mm-dd'.
+
 You can also create your own time stamp function by using `format-time-string'
 \(which see)."
   :type '(repeat (choice :menu-tag "Right Header"
@@ -3157,7 +3169,9 @@
 For symbols with bound functions, the function is called and should return a
 string to be inserted into the array.  For symbols with bound values, the value
 should be a string to be inserted into the array.  In either case, function or
-variable, the string value has PostScript string delimiters added to it."
+variable, the string value has PostScript string delimiters added to it.
+
+If symbols are unbounded, they are silently ignored."
   :version "21.1"
   :type '(repeat (choice :menu-tag "Left Footer"
 			 :tag "Left Footer"
@@ -3182,6 +3196,11 @@
 
    `ps-time-stamp-mon-dd-yyyy'		Return date as \"Jun 18 2001\".
 
+   `ps-time-stamp-yyyy-mm-dd'		Return date as \"2001-06-18\" (ISO
+					date).
+
+   `ps-time-stamp-iso8601'		Alias for `ps-time-stamp-yyyy-mm-dd'.
+
 You can also create your own time stamp function by using `format-time-string'
 \(which see)."
   :version "21.1"
@@ -3694,6 +3713,15 @@
   (format-time-string "%b %d %Y"))
 
 
+(defun ps-time-stamp-yyyy-mm-dd ()
+  "Return date as \"2001-06-18\" (ISO date)."
+  (format-time-string "%Y-%m-%d"))
+
+
+(defalias 'ps-time-stamp-iso8601 'ps-time-stamp-yyyy-mm-dd
+  "Alias for `ps-time-stamp-yyyy-mm-dd' (which see).")
+
+
 (defun ps-time-stamp-hh:mm:ss ()
   "Return time as \"17:28:31\"."
   (format-time-string "%T"))
@@ -6608,10 +6636,12 @@
 (defun ps-kill-emacs-check ()
   (let (ps-buffer)
     (and (setq ps-buffer (get-buffer ps-spool-buffer-name))
+	 (buffer-name ps-buffer)	; check if it's not killed
 	 (buffer-modified-p ps-buffer)
 	 (y-or-n-p "Unprinted PostScript waiting; print now? ")
 	 (ps-despool))
     (and (setq ps-buffer (get-buffer ps-spool-buffer-name))
+	 (buffer-name ps-buffer)	; check if it's not killed
 	 (buffer-modified-p ps-buffer)
 	 (not (yes-or-no-p "Unprinted PostScript waiting; exit anyway? "))
 	 (error "Unprinted PostScript"))))
@@ -1,7 +1,7 @@
 
 ;; Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-;; 2003 Free Software Foundation, Inc.
+;; 2003, 2004 Free Software Foundation, Inc.
 
 ;; Author: Jim Thompson (was <thompson@wg2.waii.com>)
@@ -1370,9 +1373,11 @@
 ;; level 1 compatibility.
 ;;
-;; Thanks to Colin Marquardt <colin.marquardt@usa.alcatel.com> for upside-down,
-;; line number step, line number start and zebra stripe follow suggestions, and
-;; for XEmacs beta-tests.
+;; Thanks to Colin Marquardt <colin.marquardt@usa.alcatel.com> for:
+;;    - upside-down, line number step, line number start and zebra stripe
+;;	follow suggestions.
+;;    - `ps-time-stamp-yyyy-mm-dd' and `ps-time-stamp-iso8601' suggestion.
+;;    - and for XEmacs beta-tests.
 ;;
 ;; Thanks to Klaus Berndl <klaus.berndl@sdm.de> for user defined PostScript